PlatformCheck class abstract

Class to check which is the current platform allow the compilation from web/mobile/desktop

Constructors

PlatformCheck()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAndroid bool
no setter
isIOS bool
no setter
isIOS26OrAbove bool
True on iOS 26 ("Liquid Glass") and above, where the system keyboard has rounded top corners. False on other platforms, or on iOS if the version string can't be parsed (so unknown versions fall back to the pre-iOS-26 flat-keyboard look rather than guessing).
no setter
isLinux bool
no setter
isMacOS bool
no setter
isWeb bool
no setter
isWindows bool
no setter